package com.framework.mvvm.mv

import androidx.lifecycle.*
import com.framework.mvvm.model.data.AbsentLiveData
import com.framework.mvvm.model.data.Data
import com.framework.mvvm.model.db.entity.ProjectEntity
import com.framework.mvvm.model.repository.AdmRepository
import com.framework.mvvm.model.vo.AdmRequest
import kotlinx.coroutines.launch


class AdmViewModel(private val repository: AdmRepository) : ViewModel() {
    private val _frameRequest = MutableLiveData<AdmRequest>()

    private var _projects = MutableLiveData<Data<List<ProjectEntity>>>()

    val projects: LiveData<Data<List<ProjectEntity>>> =
        Transformations.switchMap(_frameRequest) { request ->
            if (request == null) {
                AbsentLiveData.create()
            } else {
                repository.getProjects(request)
            }
        }

    fun requestFrame(request: AdmRequest) {
        _frameRequest.value = request
    }

    fun retry() {
        _frameRequest.value?.let {
            _frameRequest.value = it
        }
    }

    fun insProjects(projects: List<ProjectEntity>) {
        viewModelScope.launch {
            repository.insProject(projects)
        }
    }

    fun requestDict(request: AdmRequest) {
        viewModelScope.launch {
            repository.requestDict(request)
        }
    }

    /**
     * 请求建筑
     */
    fun requestBuilding(request: AdmRequest) {
        viewModelScope.launch {
            repository.requestBuilding(request)
        }
    }

}